@@ -53,7 +53,6 @@ service *service::cfg = NULL;
 volatile service::dialmode_t service::dialmode = service::ALL_DIALING;
 
 static struct sockaddr_storage peering;
-static char header[80] = "- welcome";
 static time_t started = 0l;
 static time_t periodic = 0l;
 
@@ -221,18 +220,15 @@ service::~service()
     memalloc::purge();
 }
 
-void service::setHeader(const char *h)
-{
-    String::set(header, sizeof(header) - 1, h);
-}
-
 void service::publish(const char *addr)
 {
     Socket::address resolver;
     struct sockaddr *host;
 
-    if(!addr)
+    if(!addr) {
         memset(&peering, 0, sizeof(peering));
+        return;
+    }
 
     int i = 0;
     resolver.set(addr, i);
