@@ -222,7 +222,7 @@ void registry::start(service *cfg)
     assert(cfg != NULL);
 
     shell::log(DEBUG1, "starting registry; mapping %d entries", mapped_entries);
-    create(REGISTRY_MAP, mapped_entries);
+    create(control::env("regmap"), mapped_entries);
     if(!reg)
         shell::log(shell::FAIL, "registry could not be mapped");
     initialize();
@@ -243,7 +243,8 @@ void registry::stop(service *cfg)
 
     shell::log(DEBUG1, "stopping registry");
     MappedMemory::release();
-    MappedMemory::remove(REGISTRY_MAP);
+    MappedMemory::remove(control::env("regmap"));
+    stats::release();
 }
 
 void registry::snapshot(FILE *fp)
@@ -547,10 +548,7 @@ void registry::reload(service *cfg)
     // if not in config file and not set, create one...
     else if(!realm) {
         memset(buffer, 0, sizeof(buffer));
-        const char *evp = getenv("HOSTNAME");
-        if(!evp)
-            evp = "none";
-        process::uuid(buffer, sizeof(buffer), evp);
+        Random::uuid(buffer);
         String::add(buffer, sizeof(buffer), ":");
         String::add(buffer, sizeof(buffer), digest);
         fsys::create(fs, "uuid", fsys::ACCESS_WRONLY, 0444);
@@ -567,7 +565,7 @@ void registry::reload(service *cfg)
 #endif
 
     if(!String::equal(realm, oldrealm)) {
-        process::uuid(session_uuid, sizeof(session_uuid), realm);
+        secure::uuid(session_uuid);
         shell::log(shell::NOTIFY, "new realm %s", realm);
         digests::clear();
     } else if(!String::equal(digest, olddigest)) {
